changeset 88657:df76808e99c0

(mail-recover-1, mail-recover): Use utf-8-emacs coding system, not emacs-mule.
author Dave Love <fx@gnu.org>
date Mon, 27 May 2002 14:51:57 +0000
parents 7b1035a6538b
children ab5d1c9248c4
files lisp/mail/sendmail.el
diffstat 1 files changed, 4 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/mail/sendmail.el	Sun May 26 22:56:19 2002 +0000
+++ b/lisp/mail/sendmail.el	Mon May 27 14:51:57 2002 +0000
@@ -1582,7 +1582,7 @@
       (define-key (current-local-map) "v"
 	(lambda ()
 	  (interactive)
-	  (let ((coding-system-for-read 'emacs-mule-unix))
+	  (let ((coding-system-for-read 'utf-8-emacs-unix))
 	    (dired-view-file))))
       (define-key (current-local-map) "\C-c\C-c"
 	(lambda ()
@@ -1590,13 +1590,13 @@
 	  (let ((fname (dired-get-filename))
 		;; Auto-saved files are written in the internal
 		;; representation, so they should be read accordingly.
-		(coding-system-for-read 'emacs-mule-unix))
+		(coding-system-for-read 'utf-8-emacs-unix))
 	    (switch-to-buffer-other-window "*mail*")
 	    (let ((buffer-read-only nil))
 	      (erase-buffer)
 	      (insert-file-contents fname nil)
 	      ;; insert-file-contents will set buffer-file-coding-system
 	      ;; to emacs-mule, which is probably not what they want to
 	      ;; use for sending the message.  But we don't know what
 	      ;; was its value before the buffer was killed or Emacs
 	      ;; crashed.  We therefore reset buffer-file-coding-system
@@ -1648,7 +1648,7 @@
 		     (buffer-coding buffer-file-coding-system)
 		     ;; Auto-save files are written in internal
 		     ;; representation of non-ASCII characters.
-		     (coding-system-for-read 'emacs-mule-unix))
+		     (coding-system-for-read 'utf-8-emacs-unix))
 		 (erase-buffer)
 		 (insert-file-contents file-name nil)
 		 (setq buffer-file-coding-system buffer-coding)))))
@@ -1590,13 +1590,13 @@
 	      (insert-file-contents fname nil)
 	      ;; insert-file-contents will set buffer-file-coding-system
-	      ;; to emacs-mule, which is probably not what they want to
+	      ;; to utf-8-emacs, which is probably not what they want to
 	      ;; use for sending the message.  But we don't know what
 	      ;; was its value before the buffer was killed or Emacs